import click
from transkribus_utils import ACDHTranskribusUtils


@click.command()
@click.option("-f", "--file-path", help="Path of the file containing the file titles")
@click.option("-r", "--regex", default=None, help="Regex for creation of collections")
@click.option("-c", "--colid", default=None, help="Collectionid for uploading the docs")
@click.option("--user", default=None, help="Transkribus user if not specified in Env")
@click.option(
    "--password", default=None, help="Transkribus password if not specified in Env"
)
@click.option(
    "--transkribus-base-url",
    default=None,
    help="Transkribus base URL if not specified in Env",
)
@click.option(
    "--goobi-base-url",
    default=None,
    help="Goobi viewer base url if not specified in Env",
)
def import_goobi_mets_to_transkribus(
    file_path,
    regex=None,
    colid=None,
    user=None,
    password=None,
    transkribus_base_url=None,
    goobi_base_url=None,
):
    transkr_utils = ACDHTranskribusUtils(
        user=user,
        password=password,
        transkribus_base_url=transkribus_base_url,
        goobi_base_url=goobi_base_url,
    )
    with open(file_path, "r") as inp:
        inp_lns = [x.strip() for x in inp.readlines()]
        if regex is not None:
            transkr_utils.upload_mets_files_from_goobi(inp_lns, col_regex=regex)
        elif colid is not None:
            transkr_utils.upload_mets_files_from_goobi(inp_lns, col_id=colid)
        else:
            raise AttributeError("You need to either specify a regex or a collectionid")


if __name__ == "__main__":
    import_goobi_mets_to_transkribus()



from setuptools import setup

with open("README.md") as readme_file:
    readme = readme_file.read()


setup(
    name="acdh-transkribus-utils",
    version="2.1",
    description="""some utility function to interact with the Transkribus-API""",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="Peter Andorfer",
    author_email="peter.andorfer@oeaw.ac.at",
    url="https://github.com/acdh-oeaw/acdh-transkribus-utils",
    packages=[
        "transkribus_utils",
    ],
    entry_points={
        "console_scripts": [
            "import-goobi-mets-to-transkribus=transkribus_utils.cli:import_goobi_mets_to_transkribus",
        ]
    },
    include_package_data=True,
    install_requires=["requests", "lxml", "click"],
    license="MIT",
    zip_safe=False,
    keywords="acdh-transkribus-utils",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Framework :: Django :: 2.0",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
    ],
)
